sec: modyfy the ABS_MT_ORIENTATION range as -4096 to 4096

Align the ABS_MT_ORIENTATION range as touch_offload.

Bug: 230270099
Test: Touch works fine.

Signed-off-by: davidycchen <davidycchen@google.com>
Change-Id: I0897533a4d59d8add8027a06597ad79d2c44a1f1
diff --git a/sec_ts.c b/sec_ts.c
index 976c982..a8b1250 100644
--- a/sec_ts.c
+++ b/sec_ts.c
@@ -3497,10 +3497,10 @@
 		input_set_abs_params(dev, ABS_MT_PRESSURE, 0,
 				     SEC_TS_PRESSURE_MAX, 0, 0);
 
 	/* Units are (-8192, 8192), representing the range between rotation
 	 * 90 degrees to left and 90 degrees to the right.
 	 */
-	input_set_abs_params(dev, ABS_MT_ORIENTATION, -8192, 8192, 0, 0);
+	input_set_abs_params(dev, ABS_MT_ORIENTATION, -4096, 4096, 0, 0);
 
 	if (propbit == INPUT_PROP_POINTER)
 		input_mt_init_slots(dev, MAX_SUPPORT_TOUCH_COUNT,
@@ -3497,10 +3497,10 @@
 				     SEC_TS_PRESSURE_MAX, 0, 0);
 
-	/* Units are (-8192, 8192), representing the range between rotation
+	/* Units are (-4096, 4096), representing the range between rotation
 	 * 90 degrees to left and 90 degrees to the right.
 	 */